@@ -2,14 +2,10 @@
 dynamic children mix-in for kivy container widgets
 ==================================================
 
-This ae portion is providing the mixin class
-:class:`DynamicChildrenBehavior` for to add children
-widgets dynamically and data-driven to your kivy
-container widgets (like DropDowns, Popups or any
-layout widgets).
-
+This ae portion is providing the mixin class :class:`DynamicChildrenBehavior` for to add children widgets dynamically
+and data-driven to your kivy container widgets (like DropDowns, Popups or any layout widgets).
 """
-from typing import Any, Dict, List
+from typing import Any, Callable, Dict, List
 
 from kivy.factory import Factory                                                            # type: ignore
 # pylint: disable=no-name-in-module
@@ -21,14 +17,14 @@ from ae.base import UNSET
 from ae.deep import deep_object, deep_replace                                               # type: ignore
 
 
-__version__ = '0.1.1'
+__version__ = '0.1.5'
 
 
 class DynamicChildrenBehavior:
     """ mixin class for the dynamic creation/refresh of child widgets from a data map.
 
-    At least one of the classes that is mixing in this class has to inherit from Widget (or EventDispatcher)
-    to get the :attr:`~DynamicChildrenBehavior.child_data_maps` attribute correctly initialized and firing on change.
+    At least one of the classes that is mixing in this class has to inherit from Widget (or EventDispatcher) to get the
+    :attr:`~DynamicChildrenBehavior.child_data_maps` attribute correctly initialized and firing on change.
     """
     child_data_maps: List[Dict[str, Any]] = ListProperty()
     """ list of child data dicts for to instantiate the children of the inheriting layout/widget.
@@ -53,6 +49,7 @@ class DynamicChildrenBehavior:
     defaults to an empty list.
     """
 
+    bind: Callable
     container: Widget
     _container: Widget
 
@@ -61,8 +58,7 @@ class DynamicChildrenBehavior:
         super().__init__(**kwargs)
         self._is_popup = isinstance(self, Popup)    # True if inherits from :class:`~kivy.uix.popup.Popup`
         self._map_children = list()
-        # noinspection PyUnresolvedReferences
-        self.fbind('on_child_data_maps', self.refresh_child_data_widgets)
+        self.bind(child_data_maps=self.refresh_child_data_widgets)
         self.refresh_child_data_widgets(self, **kwargs)
 
     def refresh_child_data_widgets(self, *_args, **init_kwargs):
@@ -104,3 +100,6 @@ class DynamicChildrenBehavior:
 
             children_container.add_widget(child)
             self._map_children.append(child)
+
+
+Factory.register('DynamicChildrenBehavior', cls=DynamicChildrenBehavior)
